==> alfresco-remote-api-23.6.1.1-sources.jar: org/alfresco/rest/workflow/api/deployments/DeploymentsRestEntityResource.java <==
/*
 * #%L
 * Alfresco Remote API
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.rest.workflow.api.deployments;

import org.alfresco.rest.framework.core.exceptions.EntityNotFoundException;
import org.alfresco.rest.framework.resource.EntityResource;
import org.alfresco.rest.framework.resource.actions.interfaces.EntityResourceAction;
import org.alfresco.rest.framework.resource.parameters.CollectionWithPagingInfo;
import org.alfresco.rest.framework.resource.parameters.Parameters;
import org.alfresco.rest.workflow.api.Deployments;
import org.alfresco.rest.workflow.api.model.Deployment;

@EntityResource(name="deployments", title = "Deployments")
public class DeploymentsRestEntityResource implements EntityResourceAction.Read<Deployment>,  
                                                      EntityResourceAction.ReadById<Deployment> {

    Deployments deployments;
    
    public void setDeployments(Deployments deployments)
    {
        this.deployments = deployments;
    }

    @Override
    public CollectionWithPagingInfo<Deployment> readAll(Parameters params)
    {
        return deployments.getDeployments(params.getPaging());
    }
    
    @Override
	public Deployment readById(String id, Parameters parameters) throws EntityNotFoundException
	{
        return deployments.getDeployment(id);
	}
}

==> alfresco-remote-api-26.1.0.39-sources.jar: org/alfresco/rest/workflow/api/deployments/DeploymentsRestEntityResource.java <==
/*
 * #%L
 * Alfresco Remote API
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.rest.workflow.api.deployments;

import org.alfresco.rest.framework.core.exceptions.EntityNotFoundException;
import org.alfresco.rest.framework.resource.EntityResource;
import org.alfresco.rest.framework.resource.actions.interfaces.EntityResourceAction;
import org.alfresco.rest.framework.resource.parameters.CollectionWithPagingInfo;
import org.alfresco.rest.framework.resource.parameters.Parameters;
import org.alfresco.rest.workflow.api.Deployments;
import org.alfresco.rest.workflow.api.model.Deployment;

@EntityResource(name = "deployments", title = "Deployments")
public class DeploymentsRestEntityResource implements EntityResourceAction.Read<Deployment>,
        EntityResourceAction.ReadById<Deployment>
{

    Deployments deployments;

    public void setDeployments(Deployments deployments)
    {
        this.deployments = deployments;
    }

    @Override
    public CollectionWithPagingInfo<Deployment> readAll(Parameters params)
    {
        return deployments.getDeployments(params.getPaging());
    }

    @Override
    public Deployment readById(String id, Parameters parameters) throws EntityNotFoundException
    {
        return deployments.getDeployment(id);
    }
}
